@@ -14,6 +14,8 @@ from Cython import Utils
 special_chars = [(u'<', u'\xF0', u'&lt;'),
                  (u'>', u'\xF1', u'&gt;'), 
                  (u'&', u'\xF2', u'&amp;')]
+                 
+line_pos_comment = re.compile(r'/\*.*?<<<<<<<<<<<<<<.*?\*/\n*', re.DOTALL)
 
 class AnnotationCCodeWriter(CCodeWriter):
 
@@ -39,9 +41,8 @@ class AnnotationCCodeWriter(CCodeWriter):
         self.annotation_buffer.write(s)
         
     def mark_pos(self, pos):
-#        if pos is not None:
-#            CCodeWriter.mark_pos(self, pos)
-#        return
+        if pos is not None:
+            CCodeWriter.mark_pos(self, pos)
         if self.last_pos:
             code = self.code.get(self.last_pos[1], "")
             self.code[self.last_pos[1]] = code + self.annotation_buffer.getvalue()
@@ -154,6 +155,7 @@ function toggleDiv(id) {
             f.write(line.rstrip())
                 
             f.write(u'</pre>\n')
+            code = re.sub(line_pos_comment, '', code) # inline annotations are redundant
             f.write(u"<pre id='line%s' class='code' style='background-color: #%s'>%s</pre>" % (k, color, code))
         f.write(u'</body></html>\n')
         f.close()
